==> zio-aws-emr_2.12-6.20.115.1-sources.jar: zio/aws/emr/model/ListBootstrapActionsRequest.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.{Marker, ClusterId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListBootstrapActionsRequest(
    clusterId: ClusterId,
    marker: Optional[Marker] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest = {
    import ListBootstrapActionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
      .builder()
      .clusterId(ClusterId.unwrap(clusterId): java.lang.String)
      .optionallyWith(
        marker.map(value => Marker.unwrap(value): java.lang.String)
      )(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ListBootstrapActionsRequest.ReadOnly =
    zio.aws.emr.model.ListBootstrapActionsRequest.wrap(buildAwsValue())
}
object ListBootstrapActionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ListBootstrapActionsRequest =
      zio.aws.emr.model
        .ListBootstrapActionsRequest(clusterId, marker.map(value => value))
    def clusterId: ClusterId
    def marker: Optional[Marker]
    def getClusterId: ZIO[Any, Nothing, ClusterId] = ZIO.succeed(clusterId)
    def getMarker: ZIO[Any, AwsError, Marker] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
  ) extends zio.aws.emr.model.ListBootstrapActionsRequest.ReadOnly {
    override val clusterId: ClusterId =
      zio.aws.emr.model.primitives.ClusterId(impl.clusterId())
    override val marker: Optional[Marker] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => zio.aws.emr.model.primitives.Marker(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
  ): zio.aws.emr.model.ListBootstrapActionsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-emr_2.13-5.17.125.1-sources.jar: zio/aws/emr/model/ListBootstrapActionsRequest.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.{Marker, ClusterId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListBootstrapActionsRequest(
    clusterId: ClusterId,
    marker: Option[Marker] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest = {
    import ListBootstrapActionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
      .builder()
      .clusterId(ClusterId.unwrap(clusterId): java.lang.String)
      .optionallyWith(
        marker.map(value => Marker.unwrap(value): java.lang.String)
      )(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ListBootstrapActionsRequest.ReadOnly =
    zio.aws.emr.model.ListBootstrapActionsRequest.wrap(buildAwsValue())
}
object ListBootstrapActionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ListBootstrapActionsRequest =
      zio.aws.emr.model
        .ListBootstrapActionsRequest(clusterId, marker.map(value => value))
    def clusterId: ClusterId
    def marker: Option[Marker]
    def getClusterId: ZIO[Any, Nothing, ClusterId] = ZIO.succeed(clusterId)
    def getMarker: ZIO[Any, AwsError, Marker] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
  ) extends zio.aws.emr.model.ListBootstrapActionsRequest.ReadOnly {
    override val clusterId: ClusterId =
      zio.aws.emr.model.primitives.ClusterId(impl.clusterId())
    override val marker: Option[Marker] = scala
      .Option(impl.marker())
      .map(value => zio.aws.emr.model.primitives.Marker(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ListBootstrapActionsRequest
  ): zio.aws.emr.model.ListBootstrapActionsRequest.ReadOnly = new Wrapper(impl)
}
